@@ -1,15 +1,15 @@
 package Net::DNS::Parameters;
 
 #
-# $Id: Parameters.pm 1740 2019-04-04 14:45:31Z willem $
+# $Id: Parameters.pm 1779 2020-05-11 09:11:17Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1740 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1779 $)[1];
 
 
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2019-03-26)
+##	(last updated 2020-05-07)
 ##
 ################################################
 
@@ -126,12 +126,12 @@ my @typebyname = (
 	MAILA	   => 254,					# RFC1035
 	ANY	   => 255,					# RFC1035 RFC6895 RFC8482
 	URI	   => 256,					# RFC7553
-	CAA	   => 257,					# RFC6844
+	CAA	   => 257,					# RFC8659
 	AVC	   => 258,					#
 	DOA	   => 259,					# draft-durand-doa-over-dns
-	AMTRELAY   => 260,					# draft-ietf-mboned-driad-amt-discovery
+	AMTRELAY   => 260,					# RFC8777
 	TA	   => 32768,					# http://cameo.library.cmu.edu/ http://www.watson.org/~weiler/INI1999-19.pdf
-	DLV	   => 32769,					# RFC4431
+	DLV	   => 32769,					# RFC8749 RFC4431
 	);
 our %typebyval = reverse( TYPE0 => 0, @typebyname );
 push @typebyname, map /^\d/ ? $_ : lc($_), @typebyname;
@@ -184,23 +184,23 @@ our %rcodebyname = @rcodebyname;
 
 # Registry: DNS EDNS0 Option Codes (OPT)
 my @ednsoptionbyname = (
-	LLQ		=> 1,					# http://files.dns-sd.org/draft-sekar-dns-llq.txt
-	UL		=> 2,					# http://files.dns-sd.org/draft-sekar-dns-ul.txt
-	NSID		=> 3,					# RFC5001
-	DAU		=> 5,					# RFC6975
-	DHU		=> 6,					# RFC6975
-	N3U		=> 7,					# RFC6975
-	'CLIENT-SUBNET' => 8,					# RFC7871
-	EXPIRE		=> 9,					# RFC7314
-	COOKIE		=> 10,					# RFC7873
-	'TCP-KEEPALIVE' => 11,					# RFC7828
-	PADDING		=> 12,					# RFC7830
-	CHAIN		=> 13,					# RFC7901
-	'KEY-TAG'	=> 14,					# RFC8145
-	'CLIENT-TAG'	=> 16,					# draft-bellis-dnsop-edns-tags
-	'SERVER-TAG'	=> 17,					# draft-bellis-dnsop-edns-tags
-
-	DEVICEID	=> 26946,				# https://docs.umbrella.com/developer/networkdevices-api/identifying-dns-traffic2
+	LLQ		 => 1,					# RFC-sekar-dns-llq-06
+	UL		 => 2,					# http://files.dns-sd.org/draft-sekar-dns-ul.txt
+	NSID		 => 3,					# RFC5001
+	DAU		 => 5,					# RFC6975
+	DHU		 => 6,					# RFC6975
+	N3U		 => 7,					# RFC6975
+	'CLIENT-SUBNET'	 => 8,					# RFC7871
+	EXPIRE		 => 9,					# RFC7314
+	COOKIE		 => 10,					# RFC7873
+	'TCP-KEEPALIVE'	 => 11,					# RFC7828
+	PADDING		 => 12,					# RFC7830
+	CHAIN		 => 13,					# RFC7901
+	'KEY-TAG'	 => 14,					# RFC8145
+	'EXTENDED-ERROR' => 15,					# RFC-ietf-dnsop-extended-error-16
+	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags
+	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags
+	DEVICEID	 => 26946,				# https://docs.umbrella.com/developer/networkdevices-api/identifying-dns-traffic2
 	);
 our %ednsoptionbyval = reverse @ednsoptionbyname;
 push @ednsoptionbyname, map /^\d/ ? $_ : lc($_), @ednsoptionbyname;
@@ -233,6 +233,10 @@ my @dsotypebyname = (
 	KEEPALIVE	  => 0x0001,				# RFC8490
 	RETRYDELAY	  => 0x0002,				# RFC8490
 	ENCRYPTIONPADDING => 0x0003,				# RFC8490
+	SUBSCRIBE	  => 0x0040,				# RFC-ietf-dnssd-push-25
+	PUSH		  => 0x0041,				# RFC-ietf-dnssd-push-25
+	UNSUBSCRIBE	  => 0x0042,				# RFC-ietf-dnssd-push-25
+	RECONFIRM	  => 0x0043,				# RFC-ietf-dnssd-push-25
 	);
 our %dsotypebyval = reverse @dsotypebyname;
 push @dsotypebyname, map /^\d/ ? $_ : lc($_), @dsotypebyname;
@@ -251,7 +255,7 @@ sub classbyname {
 		my $val = 0 + $2;
 		croak qq[classbyname("$name") out of range] if $val > 0xffff;
 		return $val;
-			}
+	}
 }
 
 sub classbyval {
@@ -261,7 +265,7 @@ sub classbyval {
 		$val += 0;
 		croak qq[classbyval($val) out of range] if $val > 0xffff;
 		return "CLASS$val";
-			}
+	}
 }
 
 
@@ -276,7 +280,7 @@ sub typebyname {
 		}
 		_typespec("$name.RRNAME") unless $typebyname{uc $name};
 		return $typebyname{uc $name} || croak qq[unknown type "$name"];
-			}
+	}
 }
 
 sub typebyval {
@@ -288,7 +292,7 @@ sub typebyval {
 		$typebyval{$val} = "TYPE$val";
 		_typespec("$val.RRTYPE");
 		return $typebyval{$val};
-			}
+	}
 }
 
 
